@@ -1,11 +1,19 @@
-# Copyright (c) 2003, 2004, 2010, 2011 Jean Forget. All rights reserved.
 # -*- encoding: utf-8; indent-tabs-mode: nil -*-
+#
+# Perl DateTime extension for providing English strings for the French Revolutionary calendar
+# Copyright (c) 2003, 2004, 2010, 2011, 2014 Jean Forget. All rights reserved.
+#
+# See the license in the embedded documentation below.
+#
 
 package DateTime::Calendar::FrenchRevolutionary::Locale::en;
 
+use utf8;
+use strict;
+use warnings;
 use vars qw($VERSION);
 
-$VERSION = '0.11'; # same as parent module DT::C::FR
+$VERSION = '0.12'; # same as parent module DT::C::FR
 
 my @months_short  = qw (Vin Fog Fro Sno Rai Win Bud Flo Mea Rea Hea Fru S-C);
 
@@ -53,115 +61,115 @@ my %time_formats = (
 my @feast = (
 # Vendémiaire
         qw(
-       grape                    saffron         ?sweet_chestnut ?colchic        horse
-       impatiens                carrot          amaranth        parsnip         vat
-       potato                   strawflower     ?squash         mignonette      donkey
-       four_o'clock_flower      pumpkin         buckwheat       sunflower       wine-press
-       hemp                     peach           turnip          amaryllis       ox
-       eggplant                 chili_pepper    tomato          barley          barrel
+       grape                saffron         ?sweet_chestnut ?colchic        horse
+       balsam               carrot          amaranth        parsnip         vat
+       potato               everlasting     ?squash         mignonette      donkey
+       four_o'clock_flower  pumpkin         buckwheat       sunflower       wine-press
+       hemp                 peach           turnip          amaryllis       ox
+       eggplant             chili_pepper    tomato          barley          barrel
         ),
 # Brumaire
         qw(
-       apple            celery          pear                    beet_root       goose
-       heliotrope       fig             black_salsify           ?whitebeam      plow
-       salsify          water_chestnut  jerusalem_artichoke     endive          turkey
-       skirret          cress           ?plumbago               pomegranate     harrow
-       ?bacchante       azarole         madder                  orange          pheasant
-       pistachio        tuberous_pea    quince                  service_tree    roller
+       apple                celery          pear                    beetroot        goose
+       heliotrope           fig             black_salsify           ?whitebeam      plow
+       salsify              water_chestnut  jerusalem_artichoke     endive          turkey
+       skirret              cress           ?plumbago               pomegranate     harrow
+       ?bacchante           azarole         madder                  orange          pheasant
+       pistachio            tuberous_pea    quince                  service_tree    roller
         ),
 # Frimaire
         qw(
-       rampion          turnip          chicory         medlar          pig
-       corn_salad       cauliflower     honey           juniper         pickaxe
-       wax              horseradish     cedar_tree      fir_tree        roe_deer
-       gorse            cypress_tree    ivy             savin_juniper   grub-hoe
-       maple_tree       heather         reed            sorrel          cricket
-       pinenut          cork            truffle         olive           shovel
+       rampion              turnip          chicory         medlar          pig
+       corn_salad           cauliflower     honey           juniper         pickaxe
+       wax                  horseradish     cedar_tree      fir_tree        roe_deer
+       gorse                cypress_tree    ivy             savin_juniper   grub-hoe
+       maple_tree           heather         reed            sorrel          cricket
+       pine_nut             cork            truffle         olive           shovel
         ),
 # Nivôse
         qw(
-       peat              coal           bitumen         sulphur         dog
-       lava              topsoil        manure          saltpeter       flail
-       granite           clay           slate           sandstone       rabbit
-       flint             marl           limestone       marble          winnowing_basket
-       gypsum            salt           iron            copper          cat
-       tin               lead           zinc            mercury         sieve
+       peat                 coal           bitumen         sulphur         dog
+       lava                 topsoil        manure          saltpeter       flail
+       granite              clay           slate           sandstone       rabbit
+       flint                marl           limestone       marble          winnowing_basket
+       gypsum               salt           iron            copper          cat
+       tin                  lead           zinc            mercury         sieve
         ),
 # Pluviôse
         qw(
-       spurge_laurel    moss            butcher's_broom snowdrop                bull
-       laurustinus      tinder_polypore mezereon        poplar_tree             axe
-       hellebore        broccoli        laurel          common_hazel            cow
-       box_tree         lichen          yew_tree        lungwort                billhook
-       pennycress       daphne          couch_grass     common_knotgrass        hare
-       woad             hazel_tree      cyclamen        celandine               sleigh
+       spurge_laurel        moss            butcher's_broom snowdrop                bull
+       laurustinus          tinder_polypore mezereon        poplar_tree             axe
+       hellebore            broccoli        laurel          common_hazel            cow
+       box_tree             lichen          yew_tree        lungwort                billhook
+       penny-cress          daphne          couch_grass     common_knotgrass        hare
+       woad                 hazel_tree      cyclamen        celandine               sleigh
         ),
 # Ventôse
         qw(
-       coltsfoot        dogwood                   ?hoary_stock      privet          billygoat
-       wild_ginger      mediterranean_buckthorn   violet            goat_willow     spade
-       narcissus        elm_tree                  fumitory          hedge_mustard   goat
-       spinach          leopard's_bane            pimpernel         chervil         line
-       mandrake         parsley                   scurvy_grass      daisy           tuna_fish
-       dandelion        windflower                maidenhair_fern   ash_tree        dibble
+       coltsfoot            dogwood                   ?hoary_stock      privet          billygoat
+       wild_ginger          mediterranean_buckthorn   violet            goat_willow     spade
+       narcissus            elm_tree                  fumitory          hedge_mustard   goat
+       spinach              leopard's_bane            pimpernel         chervil         line
+       mandrake             parsley                   scurvy-grass      daisy           tuna_fish
+       dandelion            windflower                maidenhair_fern   ash_tree        dibble
         ),
 # Germinal
         qw(
-       primula          plane_tree      asparagus       tulip           hen
-       chard            birch_tree      daffodil        alder           hatchery
-       periwinkle       hornbeam        morel           beech_tree      bee
-       lettuce          larch           hemlock         radish          hive
-       ?redbud          roman_lettuce   chestnut_tree   rocket          pigeon
-       lilac            anemone         pansy           blueberry       grafter
+       primula              plane_tree      asparagus       tulip           hen
+       chard                birch_tree      daffodil        alder           hatchery
+       periwinkle           hornbeam        morel           beech_tree      bee
+       lettuce              larch           hemlock         radish          hive
+       ?redbud              roman_lettuce   chestnut_tree   rocket          pigeon
+       lilac                anemone         pansy           blueberry       dibber
         ),
 # Floréal
         qw(
-       rose             oak_tree                fern            hawthorn        nightingale
-       columbine        lily_of_the_valley      mushroom        hyacinth        rake
-       rhubarb          sainfoin                wallflower      ?chamerops      silkworm
-       comfrey          burnet                  basket_of_gold  orache          hoe
-       ?statice         fritillary              borage          valerian        carp
-       spindletree      chive                   bugloss         wild_mustard    shepherd_staff
+       rose                 oak_tree                fern            hawthorn        nightingale
+       columbine            lily_of_the_valley      mushroom        hyacinth        rake
+       rhubarb              sainfoin                wallflower      ?chamerops      silkworm
+       comfrey              burnet                  basket_of_gold  orache          hoe
+       ?statice             fritillary              borage          valerian        carp
+       spindletree          chive                   bugloss         wild_mustard    shepherd_staff
         ),
 # Prairial
         qw(
-       alfalfa          day-lily        clover          angelica        duck
-       lemon_balm       oat_grass       martagon        wild_thyme      scythe
-       strawberry       betony          pea             acacia          quail
-       carnation        elder_tree      poppy           lime            pitchfork
-       barbel           camomile        honeysuckle     bedstraw        tench
-       jasmine          vervain         thyme           peony           carriage
+       alfalfa              day-lily        clover          angelica        duck
+       lemon_balm           oat_grass       martagon        wild_thyme      scythe
+       strawberry           betony          pea             acacia          quail
+       carnation            elder_tree      poppy           lime            pitchfork
+       barbel               camomile        honeysuckle     bedstraw        tench
+       jasmine              vervain         thyme           peony           carriage
         ),
 # Messidor
         qw(
-       rye              oats            onion           speedwell       mule
-       rosemary         cucumber        shallot         wormwood        sickle
-       coriander        artichoke       clove           lavender        chamois
-       tobacco          currant         vetchling       cherry          park
-       mint             cumin           bean            alkanet         guinea_hen
-       sage             garlic          tare            corn            shawm
+       rye                  oats            onion           speedwell       mule
+       rosemary             cucumber        shallot         wormwood        sickle
+       coriander            artichoke       clove           lavender        chamois
+       tobacco              currant         vetchling       cherry          park
+       mint                 cumin           bean            alkanet         guinea_hen
+       sage                 garlic          tare            corn            shawm
         ),
 # Thermidor
         qw(
-       spelt            mullein         melon           ryegrass        ram
-       horsetail        mugwort         safflower       blackberry      watering_can
-       ?parsnip         glasswort       apricot         basil           ewe
-       marshmallow      flax            almond          gentian         waterlock
-       carline_thistle  caper           lentil          horseheal       otter
-       myrtle           oil-seed_rape   lupin           cotton          mill
+       spelt                mullein         melon           ryegrass        ram
+       horsetail            mugwort         safflower       blackberry      watering_can
+       ?parsnip             glasswort       apricot         basil           ewe
+       marshmallow          flax            almond          gentian         waterlock
+       carline_thistle      caper           lentil          horseheal       otter
+       myrtle               oil-seed_rape   lupin           cotton          mill
         ),
 # Fructidor
         qw(
-       plum             millet          lycoperdon      barley          salmon
-       tuberose         bere            dogbane         liquorice       stepladder      
-       watermelon       fennel          barberry        walnut          trout
-       lemon            teasel          buckthorn       marigold        harverting_basket
-       wild_rose        hazelnut        hops            sorghum         crayfish
-       bitter_orange    goldenrod       corn            chestnut        basket
+       plum                 millet          lycoperdon      barley          salmon
+       tuberose             bere            dogbane         liquorice       stepladder      
+       watermelon           fennel          barberry        walnut          trout
+       lemon                teasel          buckthorn       marigold        harvesting_basket
+       wild_rose            hazelnut        hops            sorghum         crayfish
+       bitter_orange        goldenrod       corn            chestnut        basket
         ),
 # Jours complémentaires
         qw(
-       virtue            engineering    labour          opinion          rewards
+       virtue               engineering    labour          opinion          rewards
        revolution
          ));
 
@@ -245,17 +253,15 @@ sub default_datetime_format { join ' ', ( $_[0]->default_date_format, $_[0]->def
 sub default_date_format_length { $default_date_format_length }
 sub default_time_format_length { $default_time_format_length }
 
-sub month_names         { [ @months ] }
-sub month_abbreviations { [ @months_short ] }
-sub day_names           { [ @decade_days ] }
-sub day_abbreviations   { [ @decade_days_short ] }
-sub am_pms              { [ @am_pms ] }
-sub date_formats                   { \%date_formats                   }
-sub time_formats                   { \%time_formats                   }
-sub date_before_time               { $date_before_time                }
-sub _default_date_format_length    { $default_date_format_length      }
-sub _default_time_format_length    { $default_time_format_length      }
-sub date_parts_order               { $date_parts_order                }
+sub month_names                { [ @months ] }
+sub month_abbreviations        { [ @months_short ] }
+sub day_names                  { [ @decade_days ] }
+sub day_abbreviations          { [ @decade_days_short ] }
+sub am_pms                     { [ @am_pms ] }
+sub date_formats               { \%date_formats         }
+sub time_formats               { \%time_formats         }
+sub date_before_time           { $date_before_time      }
+sub date_parts_order           { $date_parts_order      }
 
 sub on_date {
   my ($self, $date) = @_;
@@ -266,78 +272,75 @@ sub on_date {
 sub _load_events {
   %event = ('dummy', split /(\d{4})\n/, <<'EVENTS');
 0101
-1 Vendémiaire I. The French troops enter Savoie
+1 Vendémiaire I The French troops enter Savoy.
 
-1 Vendémiaire III. The posts in the woods of Aachen and Reckem are
+1 Vendémiaire III The posts in the woods of Aachen and Reckem are
 taken by the Army of North.
 
 0102
-2 Vendémiaire I. Conquest of Chambéry
+2 Vendémiaire I Conquest of Chambéry.
 
-2 Vendémiaire III. The Costouge redoubt and camp are taken by the Army
-of Eastern Pyrenees.
+2 Vendémiaire III The Costouge redoubt and camp are taken by the Army of Eastern Pyrenees.
 
-2 Vendémiaire V. The Army of Italy routs the enemy at Governolo.
+2 Vendémiaire V The Army of Italy routs the enemy at Governolo.
 
 0103
-3 Vendémiaire IV. Affair of Garesio.
+3 Vendémiaire IV Affair of Garesio.
 
 0104
-4 Vendémiaire II. The Army of Alps takes the 
-Chatillon fieldworks; Piemontese rout across the Giffe river.
+4 Vendémiaire II The Army of Alps takes the Chatillon fieldworks; Piemontese rout across the Giffe river.
 
 0105
-5 Vendémiaire III. The Spanish are defeated in Olia and Monteilla by the
+5 Vendémiaire III The Spanish are defeated in Olia and Monteilla by the
 Army of Eastern Pyrenees.
 
 0106
-6 Vendémiaire III. Surrender at Crevecoeur to the Army of the North.
+6 Vendémiaire III Surrender at Crevecoeur to the Army of the North.
 
-6 Vendémiaire III. Kayserlautern, Alsborn and other surrounding posts
+6 Vendémiaire III Kayserlautern, Alsborn and other surrounding posts
 are taken again by the Army of the Rhine.
 
-6 Vendémiaire V. The enemy attacks the Army of Sambre and Meuse at
+6 Vendémiaire V The enemy attacks the Army of Sambre and Meuse at
 Wurstatt, Nider-Ulm, Ober and Nider-Ingelheim; the attack is repulsed.
 
-6 Vendémiaire XII Birth of Prosper Mérimée
+6 Vendémiaire XII Birth of Prosper Mérimée, French writer.
 
 0107
-7 Vendémiaire I. Anselme's troops conquer the city of Nice and the Montalban fortress. 
+7 Vendémiaire I Anselme's troops conquer the city of Nice and the Montalban fortress. 
 
-7 Vendémiaire II. The Army of Alps (Verdelin) defeats the enemy in the Sallanges 
+7 Vendémiaire II The Army of Alps (Verdelin) defeats the enemy in the Sallanges 
 defiles and takes the Saint-Martin redoubt.
 
 0108
-8 Vendémiaire V. 150 men from the Army of Italy sortie from Mantoue to forage.
+8 Vendémiaire V 150 men from the Army of Italy sortie from Mantoue to forage.
 They must surrender to the people of Reggio.
 
 0109
-9 Vendémiaire I. Custines' French conquer Spire.
+9 Vendémiaire I Custines' French conquer Spire.
 
-9 Vendémiaire II. The Army of Alps takes the fieldworks at
+9 Vendémiaire II The Army of Alps takes the fieldworks at
 Mont-Cormet, previously held by Piemontese.
 
 0111
-11 Vendémiaire II. Prisy's troops (Army of Alps) take the Valmeyer outpost
+11 Vendémiaire II Prisy's troops (Army of Alps) take the Valmeyer outpost
 after a bayonet charge, Saint-André's and Chamberlhac's troops take the Beaufort
 post, General-in-Chief Kellerman's troops take Moutiers and the Saint-Maurice
 town and Ledoyen's troops storm the Madeleine pass post. 
 
-11 Vendémiaire III. Battle of Aldenhoven, the Army of Sambre and Meuse
+11 Vendémiaire III Battle of Aldenhoven, the Army of Sambre and Meuse
 routs the coalised troops.
 
-11 Vendémiaire V. The Army of Rhine and Moselle attacks
+11 Vendémiaire V The Army of Rhine and Moselle attacks
 on the whole front and routs the enemy.
 
 0112
-12 Vendémiaire II. The Spanish troops are repulsed back in their camps in the Boulon 
+12 Vendémiaire II The Spanish troops are repulsed back in their camps in the Boulon 
 and Argelès by the Army of Eastern Pyrenees.
 
-12 Vendémiaire III. The land of Juliers surrenders to the Army of Sambre and Meuse.
+12 Vendémiaire III The land of Juliers surrenders to the Army of Sambre and Meuse.
 
 0113
-13 Vendémiaire I. The Austrians must leave Worms
-and Custines' troops enter the city.
+13 Vendémiaire I The Austrians must leave Worms and Custines' troops enter the city.
 
 13 Vendémiaire II Army of Eastern Pyrenees: Dagobert's troops take
 Campredon while the Colioure garrison fights and routs the Spanish cavalry.
@@ -345,64 +348,64 @@ Campredon while the Colioure garrison fights and routs the Spanish cavalry.
 13 Vendémiaire II Army of Western Pyrenees. Attacks and capture of the
 Arau and Aure valley posts.
 
-13 Vendémiaire IV. Bonaparte suppresses a royalist demonstration at the 
-Saint-Roch church in Paris
+13 Vendémiaire IV Bonaparte suppresses a royalist demonstration at the 
+Saint-Roch church in Paris.
 
 0115
-15 Vendémiaire III. Cologne surrenders to the Army of Sambre and Meuse.
+15 Vendémiaire III Cologne surrenders to the Army of Sambre and Meuse.
 
 0116
-16 Vendémiaire V. The enemy, blockaded in Mantoue by the Army of Italy
+16 Vendémiaire V The enemy, blockaded in Mantoue by the Army of Italy
 attempt a 4,600-troop sortie but fails.
 
 0117
-17 Vendémiaire I. The Austrians call off the siege of Lille.
+17 Vendémiaire I The Austrians call off the siege of Lille.
 
-17 Vendémiaire III. Fight for and capture of Frankenthal by the Army of the Rhine.
+17 Vendémiaire III Fight for and capture of Frankenthal by the Army of the Rhine.
 
 0118
-18 Vendémiaire II. Bombardment of Lyon, which opens her gates to
+18 Vendémiaire II Bombardment of Lyon, which opens her gates to
 Dubois-de-Crancé's troops.
 
-18 Vendémiaire III. Capture of Shelaudenbach and Vollfstein by the Army of the Rhine
+18 Vendémiaire III Capture of Shelaudenbach and Vollfstein by the Army of the Rhine
 which links with the Army of Moselle in Lautreck.
 
 0119
-19 Vendémiaire III. Before Maestricht, the Army of Sambre and Meuse takes back
+19 Vendémiaire III Before Maestricht, the Army of Sambre and Meuse takes back
 the Mont-Saint-Pierre castle.
 
 0120
-20 Vendémiaire III. The Army of Moselle marches on Birkenfeldt, Oberstein,
+20 Vendémiaire III The Army of Moselle marches on Birkenfeldt, Oberstein,
 Kirn and Meisenheim.
 
 0121
-21 Vendémiaire III. The Army of the North enters in Bois-le-Duc.
+21 Vendémiaire III The Army of the North enters in Bois-le-Duc.
 
 0122
-22 Vendémiaire I. Kellerman forces the Prussians to leave the city of Verdun.
+22 Vendémiaire I Kellerman forces the Prussians to leave the city of Verdun.
 He enters Verdun and continues his march to the Prussians.
 
 0123
-23 Vendémiaire III. The Army of the Rhine takes Otterberg, Rockenhausen, 
+23 Vendémiaire III The Army of the Rhine takes Otterberg, Rockenhausen, 
 Landsberg, Alzein and Oberhausen.
 
 0124
-24 Vendémiaire II. The Army of Moselle fights and routs the
+24 Vendémiaire II The Army of Moselle fights and routs the
 Coalised who had advanced on Bitche and Rorbach.
 
-24 Vendémiaire III. Fight for and capture of Gellheim and Grunstad by
+24 Vendémiaire III Fight for and capture of Gellheim and Grunstad by
 the Army of the Rhine; the French capture also Frankenthal.
 
 0125
-25 Vendémiaire II. Combat near Sarreguemines; the Army of Moselle
+25 Vendémiaire II Combat near Sarreguemines; the Army of Moselle
 repulses the enemy.
 
-25 Vendémiaire II. Queen Marie-Antoinette is beheaded.
+25 Vendémiaire II Queen Marie-Antoinette is beheaded.
 
 0126
-26 Vendémiaire I. The Austrians attack Hasnon and fail several times.
+26 Vendémiaire I The Austrians attack Hasnon and fail several times.
 
-26 Vendémiaire II. Victory of Wattignies near Maubeuge against the
+26 Vendémiaire II Victory of Wattignies near Maubeuge against the
 Austrians and end of the blockade of Maubeuge.
 
 26 Vendémiaire III The Army of Western Pyrenees takes
@@ -414,7 +417,7 @@ Moreau's troops take Creutznach and Custines' troops take Worms.
 26 Vendémiaire VI Army of Italy. Peace treaty in Campo-Formio
 near Udine between Bonaparte and the Austrians.
 
-26 Vendémiaire VI. Congress in Rastadt to conclude peace between the 
+26 Vendémiaire VI Congress in Rastadt to conclude peace between the 
 French Republic and the German Empire.
 
 0127
@@ -443,13 +446,13 @@ Austrians to leave Mayence.
 
 29 Vendémiaire III The Armée of Moselle enters Bingen.
 
-29 Vendémiaire V. The Army of Italy, debarking in Corsica,
+29 Vendémiaire V The Army of Italy, debarking in Corsica,
 captures Bastia, Saint-Florent and Bonifacio.
 
 29 Vendémiaire XIV Battle of Trafalgar.
 
 0130
-30 Vendémiaire II. The Army of Western Pyrenees
+30 Vendémiaire II The Army of Western Pyrenees
 routs three Spanish columns after a five-hour firefight.
 
 30 Vendémiaire V Army of Sambre and Meuse. Enemy crossing of the Rhine
@@ -536,7 +539,7 @@ where it is beaten and repulsed to the Segonzano village.
 crosses back after a murderous fight.
 
 0216
-16 Brumaire I. Battle of Gemmapes. Following this victory, the
+16 Brumaire I Battle of Gemmapes. Following this victory, the
 French enter Mons.
 
 16 Brumaire III Army of the North. The fort of Schenk is taken.
@@ -546,12 +549,12 @@ French enter Mons.
 garrison is repulsed by a French bayonet charge.
 
 0218
-18 Brumaire I. The French capture Tournay.
+18 Brumaire I The French capture Tournay.
 
 18 Brumaire III Army of the North. Triumphant entry of the French
 into Nimègue.
 
-18 Brumaire VIII. Bonaparte's coup: end of Directorate, beginning of Consulate
+18 Brumaire VIII Bonaparte's coup: end of Directorate, beginning of Consulate.
 
 0219
 19 Brumaire IV Army of the North. Burick taken.
@@ -568,17 +571,17 @@ between Saint-Michel and Saint-Martin, the enemy is repulsed.
 22 Brumaire I Army of the North. The city of Gand open her gates to
 the French army.
 
-22 Brumaire I. Charleroy taken by the French.
+22 Brumaire I Charleroy taken by the French.
 
 22 Brumaire III Army of the Rhine. Monbach and neighbour posts
 taken, capture of Weissenau.
 
 0223
-23 Brumaire I. Battle of Anderlecht near Bruxelles. The 
+23 Brumaire I Battle of Anderlecht near Bruxelles. The 
 French army enters in Brussels.
 
 0224
-24 Brumaire I. Capture of Frankfurt.
+24 Brumaire I Capture of Frankfurt.
 
 24 Brumaire II Army of the West. The Vendean rebels are defeated
 before the walls of Granville.
@@ -588,12 +591,12 @@ before the walls of Granville.
 on 27.
 
 0226
-26 Brumaire I. The French control the town and harbour of Ostende,
+26 Brumaire I The French control the town and harbour of Ostende,
 evacuated by the Austrians.
 
-26 Brumaire I. Saint-Remi captured.
+26 Brumaire I Saint-Remi captured.
 
-26 Brumaire I. The town of Malines capitulates.
+26 Brumaire I The town of Malines capitulates.
 
 26 Brumaire II Army of the Rhine. The army launches a surprise attack
 and captures three enemy posts near Strasburg.
@@ -626,7 +629,7 @@ Duke of Parme.
 29 Brumaire II The Army of the Rhine captures two redoubts near
 Bouxweiller.
 
-29 Brumaire VIII Birth of René Caillé, the first European to enter Timbuktu
+29 Brumaire VIII Birth of René Caillé, the first European to enter Timbuktu.
 
 0230
 30 Brumaire II Army of Eastern Pyrenees. Victorious battle at Escola,
@@ -662,7 +665,7 @@ artillery is spiked.
 0303
 3 Frimaire IV Army of Italy. Fight at Intrapa and Garesio.
 
-3 Frimaire V. Sortie by the garrison of Mantoue, which is repulsed.
+3 Frimaire V Sortie by the garrison of Mantoue, which is repulsed.
 
 0304
 4 Frimaire II Army of Italy. 800 Piemontese defeated by 500 French at
@@ -701,12 +704,12 @@ bridge and the fieldworks at Gambsheim are taken.
 11 Frimaire III Army of the Rhine And Moselle. The redoubt known as
 "Merlin redoubt" before Mayence is taken.
 
-11 Frimaire V. The enemy, arrayed in three columns, attacks the
+11 Frimaire V The enemy, arrayed in three columns, attacks the
 bridghead at Huningue and takes a fortification but is repulsed.
 
-11 Frimaire XIII. Napoleon the First is crowned Emperor of the French
+11 Frimaire XIII Napoleon the First is crowned Emperor of the French.
 
-11 Frimaire XIV. Battle of Austerlitz: the French army crushes the Austro-Russian army
+11 Frimaire XIV Battle of Austerlitz: the French army crushes the Austro-Russian army.
 
 0312
 12 Frimaire II Army of Ardennes. Strong sortie of the Givet garrison,
@@ -728,7 +731,7 @@ Salbach redoubts.
 19 Frimaire II Army of the Rhine. The Dawendorff highgrounds are captured.
 
 0320
-20 Frimaire XII Birth of Hector Berlioz
+20 Frimaire XII Birth of Hector Berlioz, French musician.
 
 0321
 21 Frimaire I Army of the North. Capture of Wezem, Wert and Ruremonde.
@@ -742,7 +745,7 @@ near Le Mans.
 near Saint-Jean-de-Luz; they must cross the Bidassoa.
 
 0324
-24 Frimaire I. The French troops take the towns
+24 Frimaire I The French troops take the towns
 of Mertzicq, Fredembourg and Saarbruck.
 
 0325
@@ -753,7 +756,7 @@ highgrounds of Marsal, Dahnbruck and Lambach.
 and redoubts that were defending Toulon.
 
 0326
-26 Frimaire I. Capture of Consarbruck.
+26 Frimaire I Capture of Consarbruck.
 
 26 Frimaire II Army of Italy. Toulon conquered, the English and
 Spanish troops flee.
@@ -852,7 +855,7 @@ Lower-Rhine department. The Vauban fort is taken back.
 29 Nivôse III Army of the North. Capture of Gertuydemberg.
 
 0430
-30 Nivôse VI Birth of Auguste Comte
+30 Nivôse VI Birth of Auguste Comte, French philosopher.
 
 0502
 2 Pluviôse I Louis XVI is beheaded.
@@ -918,7 +921,7 @@ Chauvin-Dragon.
 Adige right bank. Derunbano captured.
 
 0520
-20 Pluviôse IV Birth of Barthélémy Prosper Enfantin
+20 Pluviôse IV Birth of Barthélémy Prosper Enfantin, French social reformer.
 
 0521
 21 Pluviôse V Army of Italy. The Pope's troops, on the highground
@@ -953,7 +956,7 @@ The French, attacked in Bidole, smash the enemy. Kellerman crosses
 the Piave in San-Mamma, and routs some enemy hussards.
 
 0607
-7 Ventôse X. Birth of Victor Hugo
+7 Ventôse X. Birth of Victor Hugo.
 
 0611
 11 Ventôse III Army of Eastern Pyrenees. Bezalu captured.
@@ -970,7 +973,7 @@ di-Savaro and beat him.
 the enemy is defeated.
 
 0617
-17 Ventôse I. War is declared on the King of Spain.
+17 Ventôse I War is declared on the King of Spain.
 
 0618
 18 Ventôse II Army of the Moselle. Three Austrian battalions are
@@ -989,7 +992,7 @@ to the Vidor village and repulses the enemy.
 23 Ventôse V Army of Italy. Fight in Sacile. Fight in Bellurn, in
 which the enemy rearguard is surrounded and taken prisoner.
 
-23 Ventôse VI. After five murderous fights, the Swiss evacuate Morat.
+23 Ventôse VI After five murderous fights, the Swiss evacuate Morat.
 
 0626
 26 Ventôse V Army of Italy. Crossing of the Tagliamento, despite a
@@ -1042,7 +1045,7 @@ resistance, the enemy is routed.
 position is taken.
 
 0707
-26 Germinal V Birth of Alfred de Vigny
+7 Germinal V Birth of Alfred de Vigny, French poet.
 
 0708
 8 Germinal V Army of Italy. Enemy battalions, fresh from the Rhine
@@ -1130,7 +1133,7 @@ Austro-Sards. Fight at Dego, the enemy is routed. Fight and capture
 of Saint-Jean, in the valley of Barmida. Capture of Batisolo, Bagnosco
 and Pontenocetto. Capture of the Montezemo redoubts.
 
-26 Germinal V Birth of Adolphe Thiers
+26 Germinal V Birth of Adolphe Thiers, French writer and politician.
 
 0727
 27 Germinal II Army of the Moselle. The French occupy the highground
@@ -1188,7 +1191,7 @@ Arrola.
 4000 Spanish infantry troops and 10 Spanish cavalry squadrons rout at
 Roqueluche.
 
-7 Floréal VI Birth of Eugène Delacroix
+7 Floréal VI Birth of Eugène Delacroix, French painter.
 
 0808
 8 Floréal II Army of Eastern Pyrenees. 3000 French troops repulse
@@ -1339,7 +1342,7 @@ and Erquelinne after a 6-hour fight.
 1 Prairial IV Army of Italy. An armistice with the Duke of Modene is
 concluded.
 
-1 Prairial VII. Birth of Honoré de Balzac
+1 Prairial VII Birth of Honoré de Balzac, French writer.
 
 0904
 4 Prairial II Army of the Rhine. Battle of Schifferstadt, won
@@ -1406,7 +1409,7 @@ captured.
 14 Prairial II Army of the Ardennes. The enemy is routed near the
 Sainte-Marie woods.
 
-14 Prairial IV Birth of Sadi Carnot
+14 Prairial IV Birth of Sadi Carnot, French politician.
 
 0915
 15 Prairial II Army of Western Pyrenees. Battle won on several
@@ -1471,7 +1474,7 @@ their victorious advances until Gosselies.
 24 Prairial III Army of Sambre and Meuse. Capture of Luxembourg.
 
 0925
-25 Prairial VIII. Battle of Marengo, Italy. The same day, Kleber assassinated in Cairo
+25 Prairial VIII Battle of Marengo, Italy. The same day, general Kleber assassinated in Cairo.
 
 0926
 26 Prairial II United Armies of Moselle, Ardennes and North. Near
@@ -1571,7 +1574,7 @@ Deva.
 11 Messidor IV Army of Italy. The Milan castle capitulates.
 
 1012
-12 Messidor XII Birth of George Sand
+12 Messidor XII Birth of George Sand, French writer.
 
 1013
 13 Messidor II Army of Sambre and Meuse. Capture of the Roxule
@@ -1747,7 +1750,7 @@ of Spain.
 4 Thermidor IV Army of Sambre and Meuse. Capture of Schwinfurt.
 
 1105
-5 Thermidor X Birth of Alexandre Dumas the elder.
+5 Thermidor X Birth of Alexandre Dumas the elder, French writer.
 
 1106
 6 Thermidor II Army of Eastern Pyrenees. The Republican troops enter
@@ -1766,12 +1769,14 @@ Koenigstein fort.
 1109
 9 Thermidor I Army of Sambre and Meuse. The French enter Liège.
 
-9 Thermidor II. Robespierre's downfall.
+9 Thermidor II Robespierre's downfall.
 
 1110
 10 Thermidor II Army of the North. Capture of Cassandria and crossing
 of the Cacysche.
 
+10 Thermidor II Robespierre and several of his followers (Couthon, Saint-Just, etc) are beheaded.
+
 1111
 11 Thermidor III Army of the Alps and Italy. Assault on the redoubts
 of the di Pietri field.
@@ -1790,7 +1795,7 @@ beaten at Lonado.
 1114
 Army of Italy. Brescia taken back.
 
-14 Thermidor VII Birth of Sophie Rostopchine, later known as countess of Ségur
+14 Thermidor VII Birth of Sophie Rostopchine, later known as countess of Ségur.
 
 1115
 15 Thermidor IV Army of Sambre and Meuse. Capture of Koenigshoffen.
@@ -2076,7 +2081,7 @@ river; capture of Limbourg, Dietz and Nasseau.
 
 Army of Italy. Austrian defeat on the Borghetto line.
 
-3 additional day V. Death of general Hoche, general-in-chief of 
+3 additional day V Death of general Hoche, general-in-chief of 
 the Army of Sambre and Meuse.
 
 1304
@@ -2091,13 +2096,13 @@ are stormed, after 7 successive attacks.
 Army of Italy. Victory at Cairo over the Piemontese, supported by
 10,000 Austrians.
 
-4 additional day III. Surrender of Manheim.
+4 additional day III Surrender of Manheim.
 
 1305
 5 additional day II Army of Western Pyrenees. Spanish troops at
 Mont-Roch are routed.
 
-5 additional day IV. Death of general Marceau, aged 27, killed at
+5 additional day IV Death of general Marceau, aged 27, killed at
 Altenkirchen by a carbine shot.
 EVENTS
   delete $event{dummy};
@@ -2231,9 +2236,32 @@ L<http://en.wikipedia.org/wiki/French_Republican_Calendar>
 
 =head1 LICENSE STUFF
 
-Copyright (c)  2003, 2004, 2010,  2011, 2012 Jean Forget.   All rights
+Copyright (c)  2003, 2004, 2010,  2012, 2014 Jean Forget.   All rights
 reserved. This  program is free software. You  can distribute, modify,
 and otherwise mangle DateTime::Calendar::FrenchRevolutionary under the
-same terms as perl 5.12.2.
+same terms as perl 5.16.3.
+
+This program is  distributed under the same terms  as Perl 5.16.3: GNU
+Public License version 1 or later and Perl Artistic License
+
+You can find the text of the licenses in the F<LICENSE> file or at
+L<http://www.perlfoundation.org/artistic_license_1_0> and
+L<http://www.gnu.org/licenses/gpl-1.0.html>.
+
+Here is the summary of GPL:
+
+This program is  free software; you can redistribute  it and/or modify
+it under the  terms of the GNU General Public  License as published by
+the Free  Software Foundation; either  version 1, or (at  your option)
+any later version.
+
+This program  is distributed in the  hope that it will  be useful, but
+WITHOUT   ANY  WARRANTY;   without  even   the  implied   warranty  of
+MERCHANTABILITY  or FITNESS  FOR A  PARTICULAR PURPOSE.   See  the GNU
+General Public License for more details.
+
+You  should have received  a copy  of the  GNU General  Public License
+along with this program; if not, see <http://www.gnu.org/licenses/> or
+write to the Free Software Foundation, Inc., L<http://fsf.org>.
 
 =cut
